PropertyId

Enum PropertyId 

#[repr(u8)]
pub enum PropertyId {
Show 27 variants PayloadFormatIndicator = 1, MessageExpiryInterval = 2, ContentType = 3, ResponseTopic = 8, CorrelationData = 9, SubscriptionIdentifier = 11, SessionExpiryInterval = 17, AssignedClientIdentifier = 18, ServerKeepAlive = 19, AuthenticationMethod = 21, AuthenticationData = 22, RequestProblemInformation = 23, WillDelayInterval = 24, RequestResponseInformation = 25, ResponseInformation = 26, ServerReference = 28, ReasonString = 31, ReceiveMaximum = 33, TopicAliasMaximum = 34, TopicAlias = 35, MaximumQoS = 36, RetainAvailable = 37, UserProperty = 38, MaximumPacketSize = 39, WildcardSubscriptionAvailable = 40, SubscriptionIdentifierAvailable = 41, SharedSubscriptionAvailable = 42,
}
Property identifier.

Variants



PayloadFormatIndicator = 1

Payload format indicator (0x01).



MessageExpiryInterval = 2

Message expiry interval (0x02).



ContentType = 3

Content type (0x03).



ResponseTopic = 8

Response topic (0x08).



CorrelationData = 9

Correlation data (0x09).



SubscriptionIdentifier = 11

Subscription identifier (0x0B).



SessionExpiryInterval = 17

Session expiry interval (0x11).



AssignedClientIdentifier = 18

Assigned client identifier (0x12).



ServerKeepAlive = 19

Server keep alive (0x13).



AuthenticationMethod = 21

Authentication method (0x15).



AuthenticationData = 22

Authentication data (0x16).



RequestProblemInformation = 23

Request problem information (0x17).



WillDelayInterval = 24

Will delay interval (0x18).



RequestResponseInformation = 25

Request response information (0x19).



ResponseInformation = 26

Response information (0x1A).



ServerReference = 28

Server reference (0x1C).



ReasonString = 31

Reason string (0x1F).



ReceiveMaximum = 33

Receive maximum (0x21).



TopicAliasMaximum = 34

Topic alias maximum (0x22).



TopicAlias = 35

Topic alias (0x23).



MaximumQoS = 36

Maximum QoS (0x24).



RetainAvailable = 37

Retain available (0x25).



UserProperty = 38

User property (0x26).



MaximumPacketSize = 39

Maximum packet size (0x27).



WildcardSubscriptionAvailable = 40

Wildcard subscription available (0x28).



SubscriptionIdentifierAvailable = 41

Subscription identifier available (0x29).



SharedSubscriptionAvailable = 42

Shared subscription available (0x2A).

Implementations



impl PropertyId

pub(crate) const ALL: &[Self]

pub const fn from_vbi(v: Vbi) -> Option<Self>

Converts a raw property identifier value to the corresponding enum variant.

Returns None if the value does not correspond to a valid property identifier.

pub const fn to_vbi(self) -> Vbi

Returns the raw identifier value for this property.