Struct PropertyIdSet
pub struct PropertyIdSet(u64);Expand description
A set of property ids.
Tuple Fields
0: u64Implementations
impl PropertyIdSet
impl PropertyIdSet
pub const ALL: Self
pub const ALL: Self
A set containing all property ids.
pub const fn new() -> Self
pub const fn new() -> Self
Creates a new empty set of property ids.
pub const fn from_slice(ids: &[PropertyId]) -> Self
pub const fn from_slice(ids: &[PropertyId]) -> Self
Creates a new set from a slice of property ids.
pub const fn insert(&mut self, id: PropertyId)
pub const fn insert(&mut self, id: PropertyId)
Inserts a property id into the set.
pub const fn remove(&mut self, id: PropertyId) -> bool
pub const fn remove(&mut self, id: PropertyId) -> bool
Removes a property id from the set, returning true if it was present.
pub const fn contains(self, id: PropertyId) -> bool
pub const fn contains(self, id: PropertyId) -> bool
Returns true if the set contains the given property id.
pub const fn iter(self) -> PropertyIdSetIter ⓘ
pub const fn iter(self) -> PropertyIdSetIter ⓘ
Returns an iterator over the property ids in the set.
The order of the yielded property ids is not specified.